/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Copyright (C) Yeico S. A. de C. V.
 * xlsLib -- A multiplatform, C++ library for dynamic generation of Excel (TM) 
 * files.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *  
 * $Source: /cvsroot/xlslib/xlslib/src/xlslib/crc.h,v $
 * $Revision: 1.1.1.1 $
 * $Author: darioglz $
 * $Date: 2004/08/27 16:31:46 $
 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *
 * File description:
 *
 *
 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */


#ifndef _crc_h
#define _crc_h

#include <config.h>

#include <string>
#include "tostr.h"

#define FALSE   0
#define TRUE    !FALSE

/*
 * Select the CRC standard from the list that follows.
 */
#define CRC32

#define CRC_NAME                        "CRC-32"

#define POLYNOMIAL              0x04C11DB7
#define INITIAL_REMAINDER       0xFFFFFFFF
#define FINAL_XOR_VALUE         0xFFFFFFFF
#define REFLECT_DATA            TRUE
#define REFLECT_REMAINDER       TRUE
#define CHECK_VALUE             0xCBF43926

namespace xlslib_core
{

  typedef unsigned long  crc32_t;

  class crc
    {
    public:
      crc();
      ~crc();

      crc32_t   get(std::string& message);
      crc32_t   get();

      void operator<<(std::string newstr) { m_data += newstr; }
      void operator<<(int newdata) { m_data += str_stream(newdata); }
      void operator<<(unsigned char newdata) { m_data += str_stream(newdata); }
      void operator<<(unsigned short newdata) { m_data += str_stream(newdata); }
      void operator<<(bool newdata) { m_data += str_stream(newdata); }
      void operator<<(double newdata) { m_data += str_stream(newdata); }
  
      std::string& getdata();
    private:
      std::string m_data;
      static const crc32_t CRC_32_TABLE[256];
      unsigned long reflect(unsigned long data, unsigned char nBits);
    };

}

#endif /* _crc_h */

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * $Log: crc.h,v $
 * Revision 1.1.1.1  2004/08/27 16:31:46  darioglz
 * Initial Import.
 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

